@@ -1,6 +1,8 @@
+""" Utilities for creating rancher compatible helm charts. """
+
 from dataclasses import dataclass
 
-from ....target import Target
+from ....steps import Target
 
 
 @dataclass(frozen=True)
